@@ -1,6 +1,5 @@
 package App::cpanminus;
-our $VERSION = "1.49_02";
-$VERSION = eval $VERSION;
+our $VERSION = "1.59_01";
 
 =head1 NAME
 
@@ -10,7 +9,7 @@ App::cpanminus - get, unpack, build and install modules from CPAN
 
     cpanm Module
 
-Run C<cpanm -h> for more options.
+Run C<cpanm -h> or C<perldoc cpanm> for more options.
 
 =head1 DESCRIPTION
 
@@ -115,9 +114,9 @@ writing code.
 
 =head2 Zero-conf? How does this module get/parse/update the CPAN index?
 
-It queries the CPAN Meta DB site running on Google AppEngine at
-L<http://cpanmetadb.appspot.com/>. The site is updated every hour to reflect
-the latest changes from fast syncing mirrors. The script then also falls back
+It queries the CPAN Meta DB site at L<http://cpanmetadb.plackperl.org/>.
+The site is updated at least every hour to reflect the latest changes
+from fast syncing mirrors. The script then also falls back
 to scrape the site L<http://search.cpan.org/>.
 
 Fetched files are unpacked in C<~/.cpanm> and automatically cleaned up
@@ -229,15 +228,7 @@ The standalone executable contains the following modules embedded.
 
 =item L<JSON::PP> Copyright 2007−2011 by Makamaka Hannyaharamitu
 
-=item L<CPAN::Meta> Copyright (c) 2010 by David Golden and Ricardo Signes
-
-=item L<Try::Tiny> Copyright (c) 2009 Yuval Kogman
-
-=item L<parent> Copyright (c) 2007-10 Max Maischein
-
-=item L<Version::Requirements> copyright (c) 2010 by Ricardo Signes
-
-=item L<Dist::Metadata> copyright (c) 2011 by Randy Stauner
+=item L<CPAN::Meta> and L<CPAN::Meta::Requirements> Copyright (c) 2010 by David Golden and Ricardo Signes
 
 =item L<CPAN::Meta::YAML> copyright (c) 2010 by Adam Kennedy
 
